<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package ablog
 */

?><!doctype html>
<html <?php language_attributes(); ?>>
<head>
<meta charset="<?php bloginfo( 'charset' ); ?>">
<meta name="viewport" content="width=device-width, initial-scale=1">
<link rel="profile" href="http://gmpg.org/xfn/11">

<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'ablog' ); ?></a>

	<header id="masthead" class="site-header">
		<?php if ( get_header_image() ) : ?>
			<div id="header-image">
				<img src="<?php header_image(); ?>"  alt="<?php echo esc_attr( get_bloginfo( 'name', 'display' ) ); ?>" width="<?php echo get_custom_header()->width; ?>" height="<?php echo get_custom_header()->height; ?>" class="img-responsive">
			</div>
		<?php endif; ?>
		<div class="container">
			<div class="row">
				<div class="col-md-4 col-sm-4 col-xs-8 header-social">
					<?php do_action('ablog_header_social'); ?>
				</div>
				<div class="col-md-4 col-sm-4 col-xs-12 site-branding">
					<div class="logo text-center">
						<?php
						the_custom_logo();
						if ( is_front_page() && is_home() ) : ?>
							<h2 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h2>
						<?php else : ?>
							<h2 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h2>
						<?php endif;
						$description = get_bloginfo( 'description', 'display' );
						if ( $description || is_customize_preview() ) : ?>
							<p class="site-description"><?php echo $description; /* WPCS: xss ok. */ ?></p>
						<?php endif; ?>
					</div>
				</div><!-- .site-branding -->
				<div class="col-md-4 col-sm-4 col-xs-4 header-search">
					<ul class="list-inline text-right">
						<?php if(get_theme_mod('search_enable')) : ?>
						<li>
							<a class="search" href="#" data-toggle="modal" data-target="#search-pop"><i class="fa fa-search"></i></a>
						</li>
						<div class="modal fade search-pop" id="search-pop" tabindex="-1" role="dialog" aria-labelledby="request-a-quote">
								<div class="modal-dialog" role="document">
									<div class="modal-content">
										<div class="modal-body">
											<form role="search" method="get" class="search-fix position-relative" action="<?php echo home_url( '/' ); ?>">
												<input type="search" class="search-field form-control"
													   placeholder="<?php echo esc_attr( 'Search', 'ablog' ) ?>"
													   value="<?php echo get_search_query() ?>" name="s" />
												<button type="submit" class="btn"><i class="fa fa-long-arrow-right fa-2x"></i></button>
											</form>
										</div>
									</div>
								</div>
							</div>
						<?php endif; ?>
					</ul>
				</div>
			</div>
		</div>
		<!--------------- Primary Menu ---------------->
		<div class="primary-menu">
			<div class="container">
				<div class="row">
					<nav class="navbar navbar-default">
							<div class="navbar-header navbar-fix">
								<button type="button" data-toggle="collapse" data-target="#navbar-collapse" class="navbar-toggle">
									<span class="icon-bar"></span>
									<span class="icon-bar"></span>
									<span class="icon-bar"></span>
								</button>
							</div>
							<div id="navbar-collapse" class="navbar-collapse collapse">
								<?php
								wp_nav_menu( array(
									'theme_location'    => 'menu-1',
									'menu_id'			=> 'primary-menu',
									'container'         => '',
									'container_class'   => 'collapse navbar-collapse',
									'container_id'      => 'bs-example-navbar-collapse-1',
									'menu_class'        => 'nav navbar-nav text-capitalize text-center',
									'fallback_cb'       => 'WP_Bootstrap_Navwalker::fallback',
									'walker'            => new WP_Bootstrap_Navwalker()
								));
								?>
							</div>
						</nav>
				</div>
			</div>
		</div><!-- .Primary Menu -->
	</header><!-- #masthead -->

	<!-- breadcrumbs -->
	<?php ablog_breadcrumbs(); ?>

	<div id="content" class="site-content">
